import { NotFoundException } from '@nestjs/common';
import { QueryHandler } from '@nestjs/cqrs';
import { FindAdByUuidQuery } from '../../queries/find-ad-by-uuid.query';
import { AdsRepository } from '../../adapters/secondaries/ads.repository';
import { Messager } from '../../adapters/secondaries/messager';
import { Ad } from '../entities/ad';

@QueryHandler(FindAdByUuidQuery)
export class FindAdByUuidUseCase {
  constructor(
    private readonly repository: AdsRepository,
    private readonly messager: Messager,
  ) {}

  async execute(findAdByUuid: FindAdByUuidQuery): Promise<Ad> {
    try {
      const ad = await this.repository.findOneByUuid(findAdByUuid.uuid);
      if (!ad) throw new NotFoundException();
      return ad;
    } catch (error) {
      this.messager.publish(
        'logging.ad.read.warning',
        JSON.stringify({
          query: findAdByUuid,
          error,
        }),
      );
      throw error;
    }
  }
}
