import { hasProperPassengerSeats } from '../../domain/dtos/utils/has-passenger-seats.validator';

describe('driver and/or passenger seats validator', () => {
  it('should validate if passenger and passengers seats is not provided ', () => {
    expect(
      hasProperPassengerSeats(undefined, {
        value: undefined,
        constraints: [],
        targetName: '',
        object: {},
        property: '',
      }),
    ).toBe(true);
    expect(
      hasProperPassengerSeats(false, {
        value: undefined,
        constraints: [],
        targetName: '',
        object: {},
        property: '',
      }),
    ).toBe(true);
    expect(
      hasProperPassengerSeats(null, {
        value: undefined,
        constraints: [],
        targetName: '',
        object: {},
        property: '',
      }),
    ).toBe(true);
  });
  it('should not validate if passenger is set to true but not the related seats is not provided or 0', () => {
    expect(
      hasProperPassengerSeats(true, {
        value: undefined,
        constraints: [],
        targetName: '',
        object: {},
        property: '',
      }),
    ).toBe(false);
    expect(
      hasProperPassengerSeats(true, {
        value: undefined,
        constraints: [],
        targetName: '',
        object: { seatsPassenger: 0 },
        property: '',
      }),
    ).toBe(false);
    expect(
      hasProperPassengerSeats(true, {
        value: undefined,
        constraints: [],
        targetName: '',
        object: { seatsPassenger: undefined },
        property: '',
      }),
    ).toBe(false);
    expect(
      hasProperPassengerSeats(true, {
        value: undefined,
        constraints: [],
        targetName: '',
        object: { seatsPassenger: null },
        property: '',
      }),
    ).toBe(false);
  });
  it('should not validate if passenger seats are provided but passenger is not set or set to false ', () => {
    expect(
      hasProperPassengerSeats(false, {
        value: undefined,
        constraints: [],
        targetName: '',
        object: { seatsPassenger: 1 },
        property: '',
      }),
    ).toBe(false);
    expect(
      hasProperPassengerSeats(undefined, {
        value: undefined,
        constraints: [],
        targetName: '',
        object: { seatsPassenger: 1 },
        property: '',
      }),
    ).toBe(false);
    expect(
      hasProperPassengerSeats(null, {
        value: undefined,
        constraints: [],
        targetName: '',
        object: { seatsPassenger: 1 },
        property: '',
      }),
    ).toBe(false);
  });
});
