import { AddressRequestDTO } from '../../domain/dtos/create.address.request';
import { hasProperPositionIndexes } from '../../domain/dtos/utils/address-position.validator';
describe('addresses position validators', () => {
  const mockAddress1: AddressRequestDTO = {
    lon: 48.68944505415954,
    lat: 6.176510296462267,
    houseNumber: '5',
    street: 'Avenue Foch',
    locality: 'Nancy',
    postalCode: '54000',
    country: 'France',
  };
  const mockAddress2: AddressRequestDTO = {
    lon: 48.8566,
    lat: 2.3522,
    locality: 'Paris',
    postalCode: '75000',
    country: 'France',
  };

  const mockAddress3: AddressRequestDTO = {
    lon: 49.2628,
    lat: 4.0347,
    locality: 'Reims',
    postalCode: '51454',
    country: 'France',
  };
  it('should validate if none of position is definded ', () => {
    expect(
      hasProperPositionIndexes([mockAddress1, mockAddress2, mockAddress3]),
    ).toBeTruthy();
  });
  it('should throw an error if position are partialy defined ', () => {
    mockAddress1.position = 0;
    expect(
      hasProperPositionIndexes([mockAddress1, mockAddress2, mockAddress3]),
    ).toBeFalsy();
  });
  it('should throw an error if position are partialy defined ', () => {
    mockAddress1.position = 0;
    mockAddress2.position = null;
    mockAddress3.position = undefined;
    expect(
      hasProperPositionIndexes([mockAddress1, mockAddress2, mockAddress3]),
    ).toBeFalsy();
  });

  it('should throw an error if positions are not incremented  ', () => {
    mockAddress1.position = 0;
    mockAddress2.position = 1;
    mockAddress3.position = 1;
    expect(
      hasProperPositionIndexes([mockAddress1, mockAddress2, mockAddress3]),
    ).toBeFalsy();
  });
  it('should validate if all positions are defined and incremented', () => {
    mockAddress1.position = 0;
    mockAddress2.position = 1;
    mockAddress3.position = 2;
    expect(
      hasProperPositionIndexes([mockAddress1, mockAddress2, mockAddress3]),
    ).toBeTruthy();
    mockAddress1.position = 10;
    mockAddress2.position = 0;
    mockAddress3.position = 3;
    expect(
      hasProperPositionIndexes([mockAddress1, mockAddress2, mockAddress3]),
    ).toBeTruthy();
  });
});
