import { CreateAdRequest } from '../../domain/dtos/create-ad.request';
import { ScheduleDTO } from '../../domain/dtos/create.schedule.dto';
import { ReccurentNormaliser } from '../../domain/entities/ReccurentNormaliser';
import { Frequency } from '../../domain/types/frequency.enum';
describe('reccurent normalizer transformer for punctual ad ', () => {
  const reccurentNormaliser = new ReccurentNormaliser();
  it('should transform punctual ad into reccurent ad ', () => {
    const punctualAd: CreateAdRequest = {
      userUuid: '',
      frequency: Frequency.PUNCTUAL,
      departure: new Date('05-03-2023 12:39:39 '),
      schedule: {} as ScheduleDTO,
      addresses: [],
    };
    expect(reccurentNormaliser.fromDateResolver(punctualAd)).toBe(
      punctualAd.departure,
    );
    expect(reccurentNormaliser.toDateResolver(punctualAd)).toBe(
      punctualAd.departure,
    );
    expect(reccurentNormaliser.scheduleMonResolver(punctualAd)).toBeUndefined();
    expect(reccurentNormaliser.scheduleTueResolver(punctualAd)).toBeUndefined();
    expect(reccurentNormaliser.scheduleWedResolver(punctualAd)).toBe('12:39');
    expect(reccurentNormaliser.scheduleThuResolver(punctualAd)).toBeUndefined();
    expect(reccurentNormaliser.scheduleFriResolver(punctualAd)).toBeUndefined();
    expect(reccurentNormaliser.scheduleSatResolver(punctualAd)).toBeUndefined();
    expect(reccurentNormaliser.scheduleSunResolver(punctualAd)).toBeUndefined();
  });
  it('should leave reccurent ad as is', () => {
    const reccurentAd: CreateAdRequest = {
      userUuid: '',
      frequency: Frequency.RECURRENT,
      schedule: {
        mon: '08:30',
        tue: '08:30',
        wed: '09:00',
        fri: '09:00',
      },
      addresses: [],
    };
    expect(reccurentNormaliser.fromDateResolver(reccurentAd)).toBe(
      reccurentAd.departure,
    );
    expect(reccurentNormaliser.toDateResolver(reccurentAd)).toBe(
      reccurentAd.departure,
    );
    expect(reccurentNormaliser.scheduleMonResolver(reccurentAd)).toBe(
      reccurentAd.schedule.mon,
    );
    expect(reccurentNormaliser.scheduleTueResolver(reccurentAd)).toBe(
      reccurentAd.schedule.tue,
    );
    expect(reccurentNormaliser.scheduleWedResolver(reccurentAd)).toBe(
      reccurentAd.schedule.wed,
    );
    expect(reccurentNormaliser.scheduleThuResolver(reccurentAd)).toBe(
      reccurentAd.schedule.thu,
    );
    expect(reccurentNormaliser.scheduleFriResolver(reccurentAd)).toBe(
      reccurentAd.schedule.fri,
    );
    expect(reccurentNormaliser.scheduleSatResolver(reccurentAd)).toBe(
      reccurentAd.schedule.sat,
    );
    expect(reccurentNormaliser.scheduleSunResolver(reccurentAd)).toBe(
      reccurentAd.schedule.sun,
    );
  });
  it('should pass for each day of the week of a deprarture ', () => {
    const punctualAd: CreateAdRequest = {
      userUuid: '',
      frequency: Frequency.PUNCTUAL,
      departure: undefined,
      schedule: {} as ScheduleDTO,
      addresses: [],
    };
    punctualAd.departure = new Date('05-01-2023 ');
    expect(reccurentNormaliser.scheduleMonResolver(punctualAd)).toBe('00:00');
    punctualAd.departure = new Date('05-02-2023 06:32:45');
    expect(reccurentNormaliser.scheduleTueResolver(punctualAd)).toBe('06:32');
    punctualAd.departure = new Date('05-03-2023 10:21');
    expect(reccurentNormaliser.scheduleWedResolver(punctualAd)).toBe('10:21');
    punctualAd.departure = new Date('05-04-2023 11:06:00');
    expect(reccurentNormaliser.scheduleThuResolver(punctualAd)).toBe('11:06');
    punctualAd.departure = new Date('05-05-2023 05:20');
    expect(reccurentNormaliser.scheduleFriResolver(punctualAd)).toBe('05:20');
    punctualAd.departure = new Date('05-06-2023');
    expect(reccurentNormaliser.scheduleSatResolver(punctualAd)).toBe('00:00');
    punctualAd.departure = new Date('05-07-2023');
    expect(reccurentNormaliser.scheduleSunResolver(punctualAd)).toBe('00:00');
  });
});
